@@ -1,6 +1,6 @@
 import unittest
 
-from office.api.pdf import pdf2imgs, pdf2docx
+from office.api.pdf import pdf2imgs, pdf2docx, add_img_water
 
 
 class TestExcel(unittest.TestCase):
@@ -11,6 +11,9 @@ class TestExcel(unittest.TestCase):
 
     def test_pdf2docx(self):
         pdf2docx(
-            file_path=r'D:\work\BaiduNetdiskWorkspace\personal\linux\workplace\docs\we-media\自媒体素材\图片\社区\基础入门\Python 入门第一节\0705\常用素材\如何利用Python进行自动化办公.pdf',
-            output_path=r'C:\Users\lenovo\Desktop\package\test\output\test'
+            file_path=r'D:\如何利用Python进行自动化办公.pdf',
+            output_path=r'C:\output\test'
         )
+
+    def test_add_img_water(self):
+        add_img_water(pdf_file_in='./pdf/add_img.pdf', pdf_file_mark='./pdf/in.pdf', pdf_file_out='add_img.pdf')
